import { default as ArrowLeftSvg } from './arrow-left.svg?react';
import { default as ArrowRightSvg } from './arrow-right.svg?react';
import { ButtonHTMLAttributes } from 'react';
import { default as CaretDownSvg } from './caret-down.svg?react';
import { default as CaretUpSvg } from './caret-up.svg?react';
import { default as CircleInfoSvg } from './circle-info.svg?react';
import { CSSProperties } from 'react';
import { default as default_2 } from 'react';
import { default as DownloadSvg } from './download.svg?react';
import { default as ExpandSvg } from './expand.svg?react';
import { JSX as JSX_2 } from 'react/jsx-runtime';
import { default as LocationDotSvg } from './location-dot.svg?react';
import { MutableRefObject } from 'react';
import { default as PlaySvg } from './play.svg?react';
import { PropsWithChildren } from 'react';
import { ReactElement } from 'react';
import { ReactNode } from 'react';
import { RefCallback } from 'react';
import { default as RepeatSvg } from './repeat.svg?react';
import { default as ShuffleSvg } from './shuffle.svg?react';
import { default as XmarkSvg } from './xmark.svg?react';

export declare type Align = "auto" | "center" | "start" | "end" | "smart";

export { ArrowLeftSvg }

export { ArrowRightSvg }

export declare function Button({ active, className, children, ...props }: ButtonProps): JSX_2.Element;

declare type ButtonProps = PropsWithChildren<ButtonHTMLAttributes<HTMLButtonElement> & {
    active?: boolean;
}>;

export { CaretDownSvg }

export { CaretUpSvg }

export { CircleInfoSvg }

export declare type Control = {
    scrollToItemIdx: ScrollToItemIdxFn;
};

export declare type ControlRef = MutableRefObject<Control | null> | RefCallback<Control | null>;

export declare const defaultSlideshowTheme: SlideshowTheme;

export { DownloadSvg }

export { ExpandSvg }

export declare type ExtendedScrollBehavior = ScrollBehavior | "smart";

export declare function FixedSizeList({ style, className, orientation, itemCount, itemWidth, itemHeight, itemRenderFunction, overscanCount, controlRef, }: FixedSizeListProps): JSX_2.Element;

export declare type FixedSizeListProps = {
    orientation: Orientation;
    style?: CSSProperties;
    className?: string;
    itemCount: number;
    itemHeight: number;
    itemWidth: number;
    itemRenderFunction: ItemRenderFunction;
    overscanCount?: number;
    controlRef?: ControlRef;
};

export declare function getScrollbarSize(recalculate?: boolean): number;

export declare function Icon({ children, className, ...props }: PropsWithChildren<default_2.HTMLAttributes<HTMLSpanElement>>): JSX_2.Element;

export declare type ItemRenderFunction = (idx: number) => ReactElement | string | number;

export { LocationDotSvg }

export declare type MinimalMainItem = Pick<SlideshowItem, "url" | "mediaType">;

export declare type Orientation = "horizontal" | "vertical";

export { PlaySvg }

export declare function QuickStartSlideshow<ItemT extends SlideshowItem = SlideshowItem>(props: SlideshowProps<ItemT>): JSX_2.Element;

declare type RecursivePartial<T> = {
    [P in keyof T]?: T[P] extends (infer U)[] ? RecursivePartial<U>[] : T[P] extends object | undefined ? RecursivePartial<T[P]> : T[P];
};

export { RepeatSvg }

export declare type ScrollToItemIdxFn = (idx: number, align?: Align, behavior?: ExtendedScrollBehavior) => void;

export declare type ShortcutAction<ItemT extends SlideshowItem = SlideshowItem> = {
    handler: ShortcutHandler<ItemT>;
    stopPropagation?: boolean;
    preventDefault?: boolean;
};

export declare type ShortcutHandler<ItemT extends SlideshowItem = SlideshowItem> = (item: ItemT, e: KeyboardEvent) => void;

export declare type ShortcutsByKey<ItemT extends SlideshowItem = SlideshowItem> = Record<string, ShortcutHandler<ItemT> | ShortcutAction<ItemT> | Array<ShortcutHandler<ItemT> | ShortcutAction<ItemT>> | undefined>;

export { ShuffleSvg }

export declare function Slideshow<ItemT extends SlideshowItem = SlideshowItem>({ itemIdx, onItemIdxChange, ...otherProps }: SlideshowProps<ItemT>): JSX_2.Element;

export declare type SlideshowItem = {
    id: string;
    url: string;
    thumbnailUrl: string;
    thumbnail2xUrl?: string;
    mediaType?: string;
};

export declare function SlideshowPlaceholder({ item, onLoad, }: SlideshowPlaceholderProps): JSX_2.Element;

declare type SlideshowPlaceholderProps = {
    item: MinimalMainItem;
    onLoad?: () => void;
};

export declare type SlideshowProps<ItemT extends SlideshowItem = SlideshowItem> = {
    items: ItemT[];
    itemIdx?: number;
    onItemIdxChange?: (itemIdx: number) => void;
    topBarLeftChildren?: TopBarChildren<ItemT>;
    topBarRightChildren?: TopBarChildren<ItemT>;
    getItemUrl?: (itemIdx: number) => string | undefined;
    customShortcuts?: ShortcutsByKey<ItemT>;
    disableDefaultShortcuts?: boolean;
};

export declare type SlideshowTheme = {
    screen: {
        width: CSSProperties["width"];
        height: CSSProperties["height"];
        backgroundColor: CSSProperties["backgroundColor"];
        color: CSSProperties["color"];
        lineHeight: CSSProperties["lineHeight"];
    };
    meta: {
        hideEnabled: boolean;
        hideDelayMillis: number;
        fadeDurationMillis: number;
        barsBackgroundColor: CSSProperties["backgroundColor"];
        barsColor: CSSProperties["color"];
        barsFontSize: CSSProperties["fontSize"];
        topBarLeftChildrenPadding: CSSProperties["padding"];
        topBarLeftChildrenGap: CSSProperties["gap"];
        topBarRightChildrenPadding: CSSProperties["padding"];
        topBarRightChildrenGap: CSSProperties["gap"];
        thumbnailSizePx: number;
        thumbnailBorderSizePx: number;
        thumbnailPaddingPx: number;
        thumbnailFit: CSSProperties["objectFit"] | undefined;
    };
    button: {
        paddingX: string;
        paddingY: string;
        fontSize: CSSProperties["fontSize"];
        fontWeight: CSSProperties["fontWeight"];
        borderWidth: CSSProperties["borderWidth"];
        borderRadius: CSSProperties["borderRadius"];
        boxShadow: CSSProperties["boxShadow"];
        disabledOpacity: CSSProperties["opacity"];
        focusBoxShadow: CSSProperties["boxShadow"];
        color: CSSProperties["color"];
        backgroundColor: CSSProperties["color"];
        borderColor: CSSProperties["color"];
        hoverColor: CSSProperties["color"];
        hoverBackgroundColor: CSSProperties["color"];
        hoverBorderColor: CSSProperties["color"];
        activeColor: CSSProperties["color"];
        activeBackgroundColor: CSSProperties["color"];
        activeBorderColor: CSSProperties["color"];
        activeShadow: string;
        disabledColor: CSSProperties["color"];
        disabledBackgroundColor: CSSProperties["color"];
        disabledBorderColor: CSSProperties["color"];
    };
};

declare type SlideshowThemeOverrides = RecursivePartial<SlideshowTheme>;

export declare const SlideshowThemeSettings: ({ theme, overrides, children, }: SlideshowThemeSettingsProps) => JSX_2.Element;

declare type SlideshowThemeSettingsContextType = {
    theme?: "default";
    overrides?: SlideshowThemeOverrides;
};

declare type SlideshowThemeSettingsProps = PropsWithChildren<SlideshowThemeSettingsContextType>;

export declare type TopBarChildren<ItemT extends SlideshowItem = SlideshowItem> = ReactNode | ((props: TopBarChildrenProps<ItemT>) => ReactNode);

export declare type TopBarChildrenProps<ItemT extends SlideshowItem = SlideshowItem> = {
    itemIdx: number;
    items: ItemT[];
};

export declare function UnmanagedQuickStartSlideshow<ItemT extends SlideshowItem = SlideshowItem>(props: UnmanagedSlideshowProps<ItemT>): JSX_2.Element;

export declare function UnmanagedSlideshow<ItemT extends SlideshowItem = SlideshowItem>({ items, itemIdx, onItemIdxChange, topBarLeftChildren, topBarRightChildren, getItemUrl, customShortcuts, disableDefaultShortcuts, }: UnmanagedSlideshowProps<ItemT>): JSX_2.Element;

export declare type UnmanagedSlideshowProps<ItemT extends SlideshowItem = SlideshowItem> = SlideshowProps<ItemT> & Required<Pick<SlideshowProps<ItemT>, "onItemIdxChange">>;

export declare function useBottomBarClass(): string;

export declare function useBtnActiveClass(): string;

export declare function useBtnClass(): string;

export declare function useFadeInClass(): string;

export declare function useFadeOutClass(): string;

export declare function useIconClass(): string;

export declare function useInvisibleClass(): string;

export declare function useMetaClass(): string;

export declare function useOuterThumbnailSize(): number;

export declare function useSelectedThumbnailClass(): string;

export declare function useSlideshowScreenClass(): string;

export declare function useSlideshowTheme(): SlideshowTheme;

export declare function useThumbnailClass(): string;

export declare function useThumbnailsHorizontalListClass(): string;

export declare function useThumbnailWrapperClass(): string;

export declare function useTopBarClass(): string;

export declare function useTopBarLeftClass(): string;

export declare function useTopBarMinimizedClass(): string;

export declare function useTopBarRightClass(): string;

export declare function useZoomedDragImageClass(): string;

export { XmarkSvg }

export { }
